==> xlr-server-sql-24.1.0-1109.113-sources.jar: com/xebialabs/xlrelease/spring/config/SqlSecurityConfiguration.scala <==
package com.xebialabs.xlrelease.spring.config

import com.xebialabs.deployit.security.{PermissionChecker, PermissionEditor, UserService}
import com.xebialabs.xlrelease.config.XlrConfig
import com.xebialabs.xlrelease.security.sql._
import com.xebialabs.xlrelease.security._
import com.xebialabs.xlrelease.service.BroadcastService
import org.springframework.context.annotation.{Bean, Configuration}

import java.util.Optional

@Configuration
class SqlSecurityConfiguration(sqlConfiguration: SqlConfiguration,
                               xlrConfig: XlrConfig,
                               broadcastService: BroadcastService) {
  lazy val cachingEnabled = xlrConfig.isSecurityCacheEnabled

  @Bean
  def roleService(): SqlRoleService = if (cachingEnabled) {
    new CachingSqlRoleService(sqlConfiguration.xlrRepositoryDatabase(), broadcastService)
  } else {
    new SqlRoleService(sqlConfiguration.xlrRepositoryDatabase())
  }

  @Bean
  def userService(evicter: Optional[UserCacheEvicter]): UserService = {
    if (xlrConfig.isSecurityUserCacheEnabled) {
      new CachingSqlUserService(sqlConfiguration.xlrRepositoryDatabase(), evicter.get())
    } else {
      new SqlUserService(sqlConfiguration.xlrRepositoryDatabase())
    }
  }

  @Bean
  def userGroupService(): UserGroupService = {
    new DefaultUserGroupService(userGroupRepository())
  }

  @Bean
  def userGroupRepository(): UserGroupRepository = {
    val repository = new SqlUserGroupRepository(sqlConfiguration.ciIdService(),
      sqlConfiguration.xlrRepositoryJdbcTemplate(),
      sqlConfiguration.xlrRepositorySqlDialect())

    if (xlrConfig.isUserGroupCacheEnabled) {
      new SqlUserGroupRepositoryCache(repository, broadcastService)
    } else {
      repository
    }
  }

  @Bean
  def permissionLister(): SqlPermissionLister = if (cachingEnabled) {
    new CachingPermissionLister(sqlConfiguration.xlrRepositoryDatabase())
  } else {
    new SqlPermissionLister(sqlConfiguration.xlrRepositoryDatabase())
  }

  @Bean
  def permissionEditor(): PermissionEditor = if (cachingEnabled) {
    new CachingPermissionEditor(sqlConfiguration.xlrRepositoryDatabase(), broadcastService)
  } else {
    new SqlPermissionEditor(sqlConfiguration.xlrRepositoryDatabase())
  }

  @Bean
  def xlrPermissionChecker(permissionLister: SqlPermissionLister): PermissionChecker = {
    new SqlPermissionChecker(sqlConfiguration.xlrRepositoryDatabase(), permissionLister, cachingEnabled)
  }

}

==> xlr-server-sql-24.1.9-sources.jar: com/xebialabs/xlrelease/spring/config/SqlSecurityConfiguration.scala <==
package com.xebialabs.xlrelease.spring.config

import com.xebialabs.deployit.security.{PermissionChecker, PermissionEditor, UserService}
import com.xebialabs.xlrelease.config.XlrConfig
import com.xebialabs.xlrelease.events.XLReleaseEventBus
import com.xebialabs.xlrelease.security._
import com.xebialabs.xlrelease.security.sql._
import com.xebialabs.xlrelease.service.BroadcastService
import org.springframework.context.annotation.{Bean, Configuration}

import java.util.Optional

@Configuration
class SqlSecurityConfiguration(sqlConfiguration: SqlConfiguration,
                               xlrConfig: XlrConfig,
                               broadcastService: BroadcastService,
                               eventBus: XLReleaseEventBus) {
  lazy val cachingEnabled = xlrConfig.isSecurityCacheEnabled

  @Bean
  def roleService(): SqlRoleService = if (cachingEnabled) {
    new CachingSqlRoleService(sqlConfiguration.xlrRepositoryDatabase(), broadcastService)
  } else {
    new SqlRoleService(sqlConfiguration.xlrRepositoryDatabase())
  }

  @Bean
  def userService(evicter: Optional[UserCacheEvicter]): UserService = {
    if (xlrConfig.isSecurityUserCacheEnabled) {
      new CachingSqlUserService(sqlConfiguration.xlrRepositoryDatabase(), evicter.get())
    } else {
      new SqlUserService(sqlConfiguration.xlrRepositoryDatabase())
    }
  }

  @Bean
  def releaseRoleService(): ReleaseRoleService = {
    new DefaultReleaseRoleService(eventBus, sqlConfiguration.ciIdService(), releaseRoleRepository(), rolePermissionRepository())
  }

  @Bean
  def releaseRoleRepository(): ReleaseRoleRepository = {
    new SqlReleaseRoleRepository(
      sqlConfiguration.xlrDatabaseInformation,
      sqlConfiguration.xlrRepositoryJdbcTemplate(), sqlConfiguration.xlrRepositorySqlDialect(), roleService())
  }

  @Bean
  def userGroupService(): UserGroupService = {
    new DefaultUserGroupService(userGroupRepository())
  }

  @Bean
  def userGroupRepository(): UserGroupRepository = {
    val repository = new SqlUserGroupRepository(sqlConfiguration.ciIdService(),
      sqlConfiguration.xlrRepositoryJdbcTemplate(),
      sqlConfiguration.xlrRepositorySqlDialect())

    if (xlrConfig.isUserGroupCacheEnabled) {
      new SqlUserGroupRepositoryCache(repository, broadcastService)
    } else {
      repository
    }
  }

  @Bean
  def permissionLister(): SqlPermissionLister = if (cachingEnabled) {
    new CachingPermissionLister(sqlConfiguration.xlrRepositoryDatabase())
  } else {
    new SqlPermissionLister(sqlConfiguration.xlrRepositoryDatabase())
  }

  @Bean
  def permissionEditor(): PermissionEditor = if (cachingEnabled) {
    new CachingPermissionEditor(sqlConfiguration.xlrRepositoryDatabase(), broadcastService)
  } else {
    new SqlPermissionEditor(sqlConfiguration.xlrRepositoryDatabase())
  }

  @Bean
  def xlrPermissionChecker(permissionLister: SqlPermissionLister): PermissionChecker = {
    new SqlPermissionChecker(sqlConfiguration.xlrRepositoryDatabase(), permissionLister, cachingEnabled)
  }

  @Bean
  def rolePermissionRepository(): ReleaseRolePermissionRepository = {
    new SqlReleaseRolePermissionRepository(sqlConfiguration.xlrRepositoryDatabase())
  }

}
